@@ -1,6 +1,10 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 4.11 2006/03/25 19:24:49 bkorb Exp $
+ *  $Id: agShell.c,v 4.17 2006/09/28 01:26:33 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-24 08:48:45 bkorb"
+ *  Last Committed:    $Date: 2006/09/28 01:26:33 $
+ *
  *  Manage a server shell process
  */
 
@@ -33,7 +37,7 @@
 
  pid_t openServerFP( tpfPair* pfPair, tCC** ppArgs ) { return NOPROCESS; }
 
- char* runShell( const char* pzCmd ) {
+ char* runShell( char const* pzCmd ) {
      char* pz;
      AGDUPSTR( pz, pzCmd, "dummy shell command" );
      return pz;
@@ -52,7 +56,7 @@ static tCC     logIntroFmt[] = "\n\n* * * * LOG ENTRY %d * * * *\n";
 
 tSCC   zCmdFmt[]   = "cd %s\n%s\n\necho\necho %s - %d\n";
 
-const char* pzLastCmd = NULL;
+char const* pzLastCmd = NULL;
 
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
@@ -103,13 +107,17 @@ closeServer( void )
 static void
 sigHandler( int signo )
 {
+    static int timeout_limit = 5;
+    if ((signo == SIGALRM) && (--timeout_limit <= 0))
+        AG_ABEND( "Server shell timed out 5 times" );
+
     fprintf( pfTrace, "Closing server:  %s signal (%d) received\n",
              strsignal( signo ), signo );
     errClose = AG_TRUE;
 
     (void)fputs( "\nLast command issued:\n", pfTrace );
     {
-        const char* pz = (pzLastCmd == NULL)
+        char const* pz = (pzLastCmd == NULL)
             ? "?? unknown ??\n" : pzLastCmd;
         fprintf( pfTrace, zCmdFmt, pCurDir, pz, zShDone, logCount );
     }
@@ -132,7 +140,6 @@ serverSetup( void )
             if (p == NULL)
                 AG_ABEND( "cannot allocate path name" );
 
-            (void)atexit( &closeServer );
             pCurDir = (tpChar)getcwd( p, MAXPATHLEN );
 
             if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
@@ -158,7 +165,7 @@ serverSetup( void )
         pzLastCmd = zShellInit;
         if (pzPid == NULL)
             pzPid = zShellInit + strlen(zShellInit);
-        sprintf( pzPid, "%d\n", getpid() );
+        sprintf( pzPid, "%u\n", (unsigned int)getpid() );
         fprintf( serverPair.pfWrite, zCmdFmt, pCurDir, pzLastCmd,
                  zShDone, ++logCount );
 
@@ -236,26 +243,36 @@ chainOpen( int       stdinFd,
             pzShell = pzShellProgram;
 
         else {
-            pzShell = getenv( zShellEnv );
-            if (pzShell == NULL)
-                pzShell = "sh";
-            pzShellProgram = pzShell;
-        }
+            static char const sh_z[] = "sh";
+            static char const bin_sh[] = "/bin/sh";
 
-        /*
-         *  Disallow 'csh' and 'tcsh', or any other *csh variation.
-         *  They invariably lead to problems.
-         */
-        {
-            size_t l = strlen( pzShell );
-            if (  (l > 2)
-               && (strcmp( pzShell + l - 3, "csh" ) == 0)  )  {
-                tSCC zBadShell[] =
-                    "Your shell is '%s'.  AutoGen will attempt to use 'sh'\n";
+            pzShellProgram = getenv( zShellEnv );
+            if (pzShellProgram == NULL) {
+#               ifdef __sun
+                static char const xpg_sh[] = "/usr/xpg4/bin/sh";
+#               endif
 
-                fprintf( stdout, zBadShell, pzShell );
-                pzShell = "sh";
+            no_useful_SHELL:
+#               ifdef __sun
+                if (access(xpg_sh, X_OK) == 0)
+                    pzShellProgram = xpg_sh;
+                else
+#               endif
+                    if (access(bin_sh, X_OK) == 0)
+                         pzShellProgram = bin_sh;
+                    else pzShellProgram = sh_z;
+
+            } else {
+                char const * pze = pzShellProgram + strlen(pzShellProgram);
+                if (  ((pze - pzShellProgram) > 2)
+                   && (pze[-3] == 'c')
+                   && (pze[-2] == 's')
+                   && (pze[-1] == 'h'))  {
+                    goto no_useful_SHELL;
+                }
             }
+            putenv( aprf( "%s=%s", zShellEnv, pzShellProgram ));
+            pzShell = pzShellProgram;
         }
 
         *ppArgs = pzShell;
@@ -312,7 +329,7 @@ chainOpen( int       stdinFd,
         close( stdinFd );
         close( stdoutPair.writeFd );
         if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
-            fprintf( pfTrace, "Server shell is pid %d\n", chId );
+            fprintf(pfTrace, "Server shell is pid %u\n", (unsigned int)chId);
 
         fflush( pfTrace );
         return stdoutPair.readFd;
@@ -447,7 +464,7 @@ loadData( void )
          *  Set a timeout so we do not wait forever.  Sometimes we don't wait
          *  at all and we should.  Retry in those cases (but not on EOF).
          */
-        alarm( OPT_VALUE_TIMEOUT );
+        alarm( (unsigned int)OPT_VALUE_TIMEOUT );
         line_p = fgets( zLine, sizeof( zLine ), serverPair.pfRead );
         alarm( 0 );
 
@@ -531,7 +548,7 @@ loadData( void )
  *  we will shoot it and restart one later.
  */
 LOCAL char*
-runShell( const char*  pzCmd )
+runShell( char const*  pzCmd )
 {
     tSCC zCmdFail[] = "CLOSING SHELL SERVER - command failure:\n\t%s\n";
 
@@ -540,6 +557,8 @@ runShell( const char*  pzCmd )
      *  THEN try to start it.
      */
     if (serverId == NULLPROCESS) {
+        static char pz4_z[] = "PS4=>ag> ";
+        putenv(pz4_z);
         serverId = openServerFP( &serverPair, serverArgs );
         if (serverId > 0)
             serverSetup();
@@ -602,7 +621,6 @@ runShell( const char*  pzCmd )
 /*
  * Local Variables:
  * mode: C
- * tab-width: 4
  * c-file-style: "stroustrup"
  * indent-tabs-mode: nil
  * End:
