@@ -1,12 +1,16 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 4.8 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: autogen.c,v 4.15 2006/09/24 02:58:59 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:56:03 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -63,6 +67,7 @@ inner_main( int argc, char** argv )
     initialize( argc, argv );
 
     procState = PROC_STATE_LOAD_DEFS;
+    ag_scmStrings_init();
     readDefines();
 
     /*
@@ -78,11 +83,9 @@ inner_main( int argc, char** argv )
         processTemplate( pTF );
 
         procState = PROC_STATE_CLEANUP;
-        unloadTemplate( pTF );
+        cleanup( pTF );
     }
 
-    unloadDefs();
-
     procState = PROC_STATE_DONE;
     exit( EXIT_SUCCESS );
 }
@@ -101,9 +104,14 @@ main( int    argc,
 
     signalSetup( ignoreSignal, abendSignal );
 
+#if GUILE_VERSION >= 107000
+    if (getenv( "GUILE_WARN_DEPRECATED" ) == NULL)
+        putenv( (char*)(void*)"GUILE_WARN_DEPRECATED=no" );
+#endif
+
     gh_enter( argc, argv, inner_main );
     /* NOT REACHED */
-    return 0;
+    return EXIT_FAILURE;
 }
 
 static void
@@ -154,7 +162,7 @@ signalExit( int sig )
             line = pCurMacro->lineNo;
             fnCd = pCurMacro->funcCode;
         }
-        pzFl = pCurTemplate->pzFileName;
+        pzFl = pCurTemplate->pzTplFile;
         if (pzFl == NULL)
             pzFl = "NULL file name";
         fprintf( stderr, zAt, pzFl, line, pzFn, fnCd );
@@ -201,11 +209,15 @@ doneCheck( void )
     tSCC zErr[] =
         "Scheme evaluation error.  AutoGen ABEND-ing in template\n"
         "\t%s on line %d\n";
+#if GUILE_VERSION >= 107000
+    int exit_code = EXIT_SUCCESS;
+#endif
 
 #ifdef SHELL_ENABLED
     ag_scm_c_eval_string_from_file_line(
         "(if (> (string-length shell-cleanup) 0)"
-        "    (shell shell-cleanup) )", __FILE__, __LINE__ );
+        " (shell shell-cleanup) )", __FILE__, __LINE__ );
+    closeServer();
 #endif
 
     fflush( stdout );
@@ -216,7 +228,6 @@ doneCheck( void )
             int status;
 
             pclose( pfTrace );
-            closeServer();
             while (wait( &status ) > 0)  ;
         }
         else fclose( pfTrace );
@@ -238,7 +249,10 @@ doneCheck( void )
             pzOopsPrefix = zNil;
         }
 
-        fprintf( stderr, zErr, pCurTemplate->pzFileName, pCurMacro->lineNo );
+        if (OPT_VALUE_TRACE > TRACE_NOTHING)
+            scm_backtrace();
+
+        fprintf( stderr, zErr, pCurTemplate->pzTplFile, pCurMacro->lineNo );
 
         /*
          *  We got here because someone called exit early.
@@ -250,6 +264,10 @@ doneCheck( void )
             closeOutput( AG_TRUE );
 #endif
         } while (pCurFp->pPrev != NULL);
+
+#if GUILE_VERSION >= 107000
+        exit_code = EXIT_FAILURE;
+#endif
         break; /* continue failure exit */
 
     default:
@@ -283,11 +301,16 @@ doneCheck( void )
     /*
      *  IF we diverted stderr, then now is the time to copy the text to stdout.
      */
-    if (pzTmpStderr == NULL)
+    if (pzTmpStderr == NULL) {
+#if GUILE_VERSION >= 107000
+        if (exit_code != EXIT_SUCCESS)
+            _exit( exit_code );
+#endif
         return;
+    }
 
     do {
-        long pos = ftell( stderr );
+        unsigned long pos = ftell( stderr );
         char* pz;
 
         /*
@@ -297,7 +320,7 @@ doneCheck( void )
             break;
         pz = AGALOC( pos, "stderr redirected text" );
         rewind( stderr );
-        fread( pz, 1, pos, stderr );
+        fread(  pz, 1, pos, stderr );
         fwrite( pz, 1, pos, stdout );
         AGFREE( pz );
     } while (0);
@@ -306,6 +329,10 @@ doneCheck( void )
     unlink( pzTmpStderr );
     AGFREE( pzTmpStderr );
     pzTmpStderr = NULL;
+#if GUILE_VERSION >= 107000
+    if (exit_code != EXIT_SUCCESS)
+        _exit( exit_code );
+#endif
 }
 
 
@@ -328,7 +355,7 @@ ag_abend_at( tCC* pzMsg
     if ((procState >= PROC_STATE_LIB_LOAD) && (pCurTemplate != NULL)) {
         int line = (pCurMacro == NULL) ? -1 : pCurMacro->lineNo;
         fprintf( stderr, "Error in template %s, line %d\n\t",
-                 pCurTemplate->pzFileName, line );
+                 pCurTemplate->pzTplFile, line );
     }
     fputs( pzMsg, stderr );
     pzMsg += strlen( pzMsg );
@@ -394,6 +421,17 @@ signalSetup( sighandler_proc_t* chldHandler,
         case SIGSTOP:
             continue;
 
+#if defined(DEBUG_ENABLED)
+        case SIGBUS:
+        case SIGSEGV:
+            /*
+             *  While debugging AutoGen, we want seg faults to happen and
+             *  trigger core dumps.  Make sure this happens.
+             */
+            sa.sa_handler = SIG_DFL;
+            break;
+#endif
+
             /*
              *  Signals to ignore with SIG_IGN.
              */
@@ -415,6 +453,7 @@ signalSetup( sighandler_proc_t* chldHandler,
 
 #ifdef DAEMON_ENABLED
 # error DAEMON-ization of AutoGen is not ready for prime time
+  Choke Me.
         case SIGHUP:
             if (HAVE_OPT( DAEMON )) {
                 sa.sa_handler = handleSighup;
@@ -438,11 +477,53 @@ signalSetup( sighandler_proc_t* chldHandler,
 #  include <compat/strsignal.c>
 #endif
 
+LOCAL void *
+ao_malloc (size_t sz)
+{
+    void * res = malloc(sz);
+    if (res == NULL) {
+        fprintf( stderr, "malloc of %d bytes failed\n", sz );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
+
+LOCAL void *
+ao_realloc (void *p, size_t sz)
+{
+    void * res = realloc(p, sz);
+    if (res == NULL) {
+        fprintf( stderr, "realloc of %d bytes at 0x%p failed\n", sz, p );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
+
+LOCAL void
+ao_free (void *p)
+{
+    if (p != NULL)
+        free(p);
+}
+
+
+LOCAL char *
+ao_strdup (char const * str)
+{
+    char * res = strdup(str);
+    if (res == NULL) {
+        fprintf( stderr, "strdup of %d byte string failed\n", strlen(str) );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
 /*
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/autogen.c */
