@@ -1,13 +1,17 @@
 
 /*
  *  expString.c
- *  $Id: expString.c,v 4.4 2005/01/24 00:00:32 bkorb Exp $
+ *  $Id: expString.c,v 4.14 2006/09/24 02:58:59 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:52:39 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *
  *  This module implements expression functions that
  *  manipulate string values.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -22,8 +26,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 /* = = = START-STATIC-FORWARD = = = */
@@ -34,7 +38,7 @@ makeString( tCC*    pzText,
             size_t  newLineSize );
 
 static SCM
-shell_stringify( SCM obj, char qt );
+shell_stringify( SCM obj, u_int qt );
 
 static void
 do_substitution(
@@ -159,11 +163,6 @@ makeString( tCC*    pzText,
             pzDta += newLineSize;
             break;
 
-        case '\t':
-            *(pzDta++) = '\\';
-            *(pzDta++) = 't';
-            break;
-
         case '\a':
             *(pzDta++) = '\\';
             *(pzDta++) = 'a';
@@ -184,6 +183,11 @@ makeString( tCC*    pzText,
             *(pzDta++) = 'r';
             break;
 
+        case '\t':
+            *(pzDta++) = '\\';
+            *(pzDta++) = 't';
+            break;
+
         case '\v':
             *(pzDta++) = '\\';
             *(pzDta++) = 'v';
@@ -222,7 +226,7 @@ makeString( tCC*    pzText,
 
 
 static SCM
-shell_stringify( SCM obj, char qt )
+shell_stringify( SCM obj, u_int qt )
 {
     char*  pzDta;
     char*  pzNew;
@@ -245,7 +249,7 @@ shell_stringify( SCM obj, char qt )
                 break;
 
             default:
-                dtaSize++;            
+                dtaSize++;
             }
         } loopDone1:;
     }
@@ -308,12 +312,12 @@ shell_stringify( SCM obj, char qt )
         } loopDone2:;
 
         pz[-1]  = qt;
+        *pz     = NUL;
         dtaSize = (pz - pzNew);
     }
 
     {
-        SCM res = scm_makstr( (scm_sizet)dtaSize, 0 );
-        memcpy( SCM_CHARS( res ), pzNew, dtaSize );
+        SCM res = AG_SCM_STR2SCM( pzNew, dtaSize );
         AGFREE( pzNew );
         return res;
     }
@@ -337,8 +341,8 @@ do_substitution(
 {
     char* pzMatch = ag_scm2zchars( match, "match text" );
     char* pzRepl  = ag_scm2zchars( repl,  "repl text" );
-    int   matchL  = SCM_LENGTH( match );
-    int   replL   = SCM_LENGTH( repl );
+    int   matchL  = AG_SCM_STRLEN( match );
+    int   replL   = AG_SCM_STRLEN( repl );
     int   endL    = strLen;
 
     int   repCt   = 0;
@@ -370,10 +374,10 @@ do_substitution(
         if (pzNxt == NULL)
             break;
         if (pz != pzNxt) {
-            memcpy( pzScan, pz, (pzNxt - pz) );
+            memcpy( pzScan, pz, (unsigned)(pzNxt - pz) );
             pzScan += (pzNxt - pz);
         }
-        memcpy( pzScan, pzRepl, replL );
+        memcpy( pzScan, pzRepl, (unsigned)replL );
         pzScan += replL;
         pz = pzNxt + matchL;
     }
@@ -413,7 +417,7 @@ do_multi_subs(
         match = SCM_CDR( match );
         repl  = SCM_CDR( repl );
 
-        if (gh_string_p( matchCar )) {
+        if (AG_SCM_STRING_P( matchCar )) {
             do_substitution( pzStr, *pStrLen, matchCar, replCar,
                              &pzNxt, pStrLen );
 
@@ -456,24 +460,24 @@ do_multi_subs(
 SCM
 ag_scm_in_p( SCM obj, SCM list )
 {
-    int   len;
-    int   lenz;
-    SCM   car;
-    char* pz1;
+    int     len;
+    size_t  lenz;
+    SCM     car;
+    tCC *   pz1;
 
-    if (! gh_string_p( obj ))
+    if (! AG_SCM_STRING_P( obj ))
         return SCM_UNDEFINED;
 
-    pz1  = SCM_CHARS(  obj );
-    lenz = SCM_LENGTH( obj );
+    pz1  = AG_SCM_CHARS(  obj );
+    lenz = AG_SCM_STRLEN( obj );
 
     /*
      *  If the second argument is a string somehow, then treat
      *  this as a straight out string comparison
      */
-    if (gh_string_p( list )) {
-        if (  (SCM_LENGTH( list ) == lenz)
-           && (strncmp( pz1, SCM_CHARS( list ), lenz ) == 0) )
+    if (AG_SCM_STRING_P( list )) {
+        if (  (AG_SCM_STRLEN( list ) == lenz)
+           && (strncmp( pz1, AG_SCM_CHARS( list ), lenz) == 0))
             return SCM_BOOL_T;
         return SCM_BOOL_F;
     }
@@ -495,14 +499,14 @@ ag_scm_in_p( SCM obj, SCM list )
          *  hands it to us, it magically becomes a nested list.
          *  This unravels that.
          */
-        if (! gh_string_p( car )) {
+        if (! AG_SCM_STRING_P( car )) {
             if (ag_scm_in_p( obj, car ) == SCM_BOOL_T)
                 return SCM_BOOL_T;
             continue;
         }
 
-        if (  (SCM_LENGTH( car ) == lenz)
-           && (strncmp( pz1, SCM_CHARS( car ), lenz ) == 0) )
+        if (  (AG_SCM_STRLEN( car ) == lenz)
+           && (strncmp( pz1, AG_SCM_CHARS( car ), lenz ) == 0) )
             return SCM_BOOL_T;
     }
 
@@ -528,21 +532,21 @@ ag_scm_join( SCM sep, SCM list )
     int        l_len, sv_l_len;
     SCM        car;
     SCM        alist = list;
-    char*      pzSep;
-    int        sep_len;
+    size_t     sep_len;
     scm_sizet  str_len;
-    SCM        res;
     char*      pzRes;
+    tCC *      pzSep;
+    char*      pzScan;
 
-    if (! gh_string_p( sep ))
+    if (! AG_SCM_STRING_P( sep ))
         return SCM_UNDEFINED;
 
     sv_l_len = l_len = scm_ilength( list );
     if (l_len == 0)
-        return gh_str02scm( "" );
+        return AG_SCM_STR02SCM( "" );
 
-    pzSep   = SCM_ROCHARS( sep );
-    sep_len = SCM_LENGTH( sep );
+    pzSep   = AG_SCM_CHARS( sep );
+    sep_len = AG_SCM_STRLEN( sep );
     str_len = 0;
 
     /*
@@ -558,14 +562,14 @@ ag_scm_join( SCM sep, SCM list )
          *  hands it to us, it magically becomes a nested list.
          *  This unravels that.
          */
-        if (! gh_string_p( car )) {
+        if (! AG_SCM_STRING_P( car )) {
             if (car != SCM_UNDEFINED)
                 car = ag_scm_join( sep, car );
-            if (! gh_string_p( car ))
+            if (! AG_SCM_STRING_P( car ))
                 return SCM_UNDEFINED;
         }
 
-        str_len += SCM_LENGTH( car );
+        str_len += AG_SCM_STRLEN( car );
 
         if (--l_len <= 0)
             break;
@@ -574,14 +578,13 @@ ag_scm_join( SCM sep, SCM list )
     }
 
     l_len = sv_l_len;
-    res   = scm_makstr( str_len, 0 );
-    pzRes = SCM_CHARS( res );
+    pzRes = pzScan = ag_scribble( str_len );
 
     /*
      *  Now, copy each one into the output
      */
     for (;;) {
-        int cpy_len;
+        size_t cpy_len;
 
         car   = SCM_CAR( alist );
         alist = SCM_CDR( alist );
@@ -589,23 +592,23 @@ ag_scm_join( SCM sep, SCM list )
         /*
          *  This unravels nested lists.
          */
-        if (! gh_string_p( car ))
+        if (! AG_SCM_STRING_P( car ))
             car = ag_scm_join( sep, car );
 
-        cpy_len = SCM_LENGTH( car );
-        memcpy( (void*)pzRes, SCM_ROCHARS( car ), cpy_len );
-        pzRes += cpy_len;
+        cpy_len = AG_SCM_STRLEN( car );
+        memcpy( (void*)pzScan, AG_SCM_CHARS( car ), cpy_len );
+        pzScan += cpy_len;
 
         /*
          *  IF we reach zero, then do not insert a separation and bail out
          */
         if (--l_len <= 0)
             break;
-        memcpy( (void*)pzRes, (void*)pzSep, sep_len );
-        pzRes += sep_len;
+        memcpy( (void*)pzScan, (void*)pzSep, sep_len );
+        pzScan += sep_len;
     }
 
-    return res;
+    return AG_SCM_STR2SCM( pzRes, str_len );
 }
 
 
@@ -638,9 +641,9 @@ ag_scm_prefix( SCM prefix, SCM text )
     char*    pzPfx;
     char*    pzText;
     char*    pzDta;
-    size_t   out_size;
+    size_t   out_size, rem_size;
     size_t   pfx_size;
-    SCM      res;
+    char*    pzRes;
 
     pzPfx   = ag_scm2zchars( prefix, "prefix" );
     pzDta   = \
@@ -660,32 +663,31 @@ ag_scm_prefix( SCM prefix, SCM text )
         }
     } exit_count:;
 
-    res    = scm_makstr( (scm_sizet)out_size, 0 );
     pzText = pzDta;
-    pzDta  = SCM_CHARS( res );
+    pzRes  = pzDta = ag_scribble( rem_size = out_size );
     strcpy( pzDta, pzPfx );
     pzDta    += pfx_size;
-    out_size -= pfx_size;
+    rem_size -= pfx_size;
     pfx_size++;
 
     for (;;) {
         char ch = *(pzText++);
         switch (ch) {
         case NUL:
-            if (out_size != 0)
+            if (rem_size != 0)
                 AG_ABEND( "(prefix ...) failed" );
 
-            return res;
+            return AG_SCM_STR2SCM( pzRes, out_size );
 
         case '\n':
             *pzDta    = ch;
             strcpy( pzDta+1, pzPfx );
             pzDta    += pfx_size;
-            out_size -= pfx_size;
+            rem_size -= pfx_size;
             break;
 
         default:
-            out_size--;
+            rem_size--;
             *(pzDta++) = ch;
             break;
         }
@@ -717,11 +719,11 @@ ag_scm_prefix( SCM prefix, SCM text )
 SCM
 ag_scm_shell( SCM cmd )
 {
-    if (! gh_string_p( cmd ))
+    if (! AG_SCM_STRING_P( cmd ))
         return SCM_UNDEFINED;
     {
         char* pz = runShell( ag_scm2zchars( cmd, "command" ));
-        cmd   = gh_str02scm( pz );
+        cmd   = AG_SCM_STR02SCM( pz );
         AGFREE( (void*)pz );
         return cmd;
     }
@@ -754,7 +756,7 @@ ag_scm_shellf( SCM fmt, SCM alist )
     fmt = run_printf( pz, len, alist );
 
     pz  = runShell( ag_scm2zchars( fmt, "shell script" ));
-    fmt = gh_str02scm( pz );
+    fmt = AG_SCM_STR02SCM( pz );
     AGFREE( (void*)pz );
     return fmt;
 }
@@ -789,7 +791,7 @@ ag_scm_raw_shell_str( SCM obj )
     pzDta = ag_scm2zchars( obj, "AG Object" );
 
     {
-        size_t dtaSize = SCM_LENGTH( obj ) + 3; /* NUL + 2 quotes */
+        size_t dtaSize = AG_SCM_STRLEN( obj ) + 3; /* NUL + 2 quotes */
         pz = pzDta-1;
         for (;;) {
             pz = strchr( pz+1, '\'' );
@@ -924,7 +926,7 @@ ag_scm_raw_shell_str( SCM obj )
 SCM
 ag_scm_shell_str( SCM obj )
 {
-    return shell_stringify( obj, '"' );
+    return shell_stringify( obj, (unsigned)'"' );
 }
 
 /*=gfunc sub_shell_str
@@ -942,7 +944,7 @@ ag_scm_shell_str( SCM obj )
 SCM
 ag_scm_sub_shell_str( SCM obj )
 {
-    return shell_stringify( obj, '`' );
+    return shell_stringify( obj, (unsigned)'`' );
 }
 
 
@@ -979,7 +981,7 @@ ag_scm_stack( SCM obj )
         if (pDE->valType != VALTYP_TEXT)
             return SCM_UNDEFINED;
 
-        str  = gh_str02scm( pDE->val.pzText );
+        str  = AG_SCM_STR02SCM( pDE->val.pzText );
         *pos = scm_cons( str, SCM_EOL );
         pos  = SCM_CDRLOC( *pos );
     }
@@ -1104,8 +1106,9 @@ ag_scm_string_tr_x( SCM str, SCM from_xform, SCM to_xform )
             }
         } mapDone:;
 
-        pzTo = ag_scm2zchars( str, "string" );
-        while (*pzTo != NUL) {
+        pzTo = (char*)(void*)AG_SCM_CHARS( str );
+        i    = AG_SCM_STRLEN( str );
+        while (i-- > 0) {
             *pzTo = map[ (int)*pzTo ];
             pzTo++;
         }
@@ -1129,10 +1132,8 @@ ag_scm_string_tr_x( SCM str, SCM from_xform, SCM to_xform )
 SCM
 ag_scm_string_tr( SCM Str, SCM From, SCM To )
 {
-    scm_sizet lenz  = SCM_LENGTH( Str );
-    SCM       res   = scm_makstr( lenz, 0 );
-    char*     pzDta = SCM_CHARS( res );
-    memcpy( pzDta, SCM_CHARS( Str ), lenz );
+    scm_sizet lenz  = AG_SCM_STRLEN( Str );
+    SCM       res   = AG_SCM_STR2SCM( AG_SCM_CHARS(Str), lenz );
     return ag_scm_string_tr_x( res, From, To );
 }
 
@@ -1164,26 +1165,25 @@ ag_scm_string_substitute( SCM Str, SCM Match, SCM Repl )
     scm_sizet  len;
     SCM        res;
 
-    if (! gh_string_p( Str ))
+    if (! AG_SCM_STRING_P( Str ))
         return SCM_UNDEFINED;
 
-    pzStr = SCM_ROCHARS( Str );
-    len   = SCM_LENGTH( Str );
+    pzStr = AG_SCM_CHARS( Str );
+    len   = AG_SCM_STRLEN( Str );
 
-    if (gh_string_p( Match ))
+    if (AG_SCM_STRING_P( Match ))
         do_substitution( pzStr, len, Match, Repl,
                          (char**)&pzStr, &len );
     else
         do_multi_subs( (char**)&pzStr, &len, Match, Repl );
 
-    res = scm_makstr( len, 0 );
-    memcpy( SCM_CHARS( res ), pzStr, len );
+    res = AG_SCM_STR2SCM( pzStr, len );
 
     /*
      *  IF we have an allocated intermediate result,
      *  THEN we must free it.  We might have our original string.
      */
-    if (pzStr != SCM_ROCHARS( Str ))
+    if (pzStr != AG_SCM_CHARS( Str ))
         AGFREE( (char*)pzStr );
     return res;
 }
@@ -1192,7 +1192,6 @@ ag_scm_string_substitute( SCM Str, SCM Match, SCM Repl )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expString.c */
