@@ -1,6 +1,9 @@
 
 /*
- *  $Id: funcFor.c,v 4.10 2006/03/25 19:24:49 bkorb Exp $
+ *  $Id: funcFor.c,v 4.15 2006/09/24 02:59:00 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:51:40 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:59:00 $
  *
  *  This module implements the FOR text macro.
  */
@@ -47,7 +50,7 @@ doForEach( tTemplate*   pT,
            tDefEntry*   pFoundDef );
 
 static void
-load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac );
+load_ForIn( tCC* pzSrc, u_int srcLen, tTemplate* pT, tMacro* pMac );
 /* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -311,7 +314,7 @@ doForByStep( tTemplate* pT,
     tDefCtx     ctx       = currDefCtx;
 
     if (pFS->for_pzSep == NULL)
-        pFS->for_pzSep = "";
+        pFS->for_pzSep = (char*)zNil;
 
     /*
      *  IF the for-from and for-to values have not been set,
@@ -361,11 +364,11 @@ doForByStep( tTemplate* pT,
         if (loopLimit-- < 0) {
             fprintf( pfTrace, "too many FOR iterations in %s line %d\n",
                      pT->pzTplName, pMac->lineNo );
-            fprintf( pfTrace, "\texiting FOR %s from %d to %d "
-                     "by %d:\n\tmore than %ld iterations\n",
+            fprintf( pfTrace, "\texiting FOR %s from %d to %d by %d:\n"
+                     "\tmore than %d iterations\n",
                      pT->pzTemplText + pMac->ozText,
                      pFS->for_from, pFS->for_to, pFS->for_by,
-                     OPT_VALUE_LOOP_LIMIT );
+                     (int)OPT_VALUE_LOOP_LIMIT );
             break;
         }
 
@@ -495,7 +498,7 @@ doForEach( tTemplate*   pT,
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 static void
-load_ForIn( tCC* pzSrc, int srcLen, tTemplate* pT, tMacro* pMac )
+load_ForIn( tCC* pzSrc, u_int srcLen, tTemplate* pT, tMacro* pMac )
 {
     char* pzName = pT->pzTemplText + pMac->ozName;
     int   ix     = 0;
@@ -760,7 +763,7 @@ tMacro*
 mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     char*   pzCopy = pT->pNext; /* next text dest   */
-    tCC*    pzSrc  = (const char*)pMac->ozText; /* macro text */
+    tCC*    pzSrc  = (char const*)pMac->ozText; /* macro text */
     int     srcLen = (int)pMac->res;            /* macro len  */
     tMacro* pEndMac;
 
@@ -823,7 +826,7 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      */
     else if (   (strneqvcmp( pzSrc, "in", 2 ) == 0)
              && isspace( pzSrc[2] )) {
-        load_ForIn( pzSrc, srcLen, pT, pMac );
+        load_ForIn( pzSrc, (unsigned)srcLen, pT, pMac );
     }
 
     /*
@@ -855,7 +858,6 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/funcFor.c */
