@@ -1,10 +1,10 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Thu Dec 15 15:11:46 PST 2005
+ * Generated Sat Sep 30 12:32:04 PDT 2006
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
-#define AUTOOPTS_PROTO_H_GUARD
+#define AUTOOPTS_PROTO_H_GUARD 1
 #ifndef LOCAL
 #  define LOCAL extern
 #  define REDEF_LOCAL 1
@@ -14,6 +14,18 @@
 /*
  *  Extracted from autoopts.c
  */
+LOCAL void *
+ao_malloc( size_t sz );
+
+LOCAL void *
+ao_realloc( void *p, size_t sz );
+
+LOCAL void
+ao_free( void *p );
+
+LOCAL char *
+ao_strdup( char const *str );
+
 LOCAL tSuccess
 handleOption( tOptions* pOpts, tOptState* pOptState );
 
@@ -21,7 +33,7 @@ LOCAL tSuccess
 longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );
 
 LOCAL tSuccess
-shortOptionFind( tOptions* pOpts, tAoUC optValue, tOptState* pOptState );
+shortOptionFind( tOptions* pOpts, uint_t optValue, tOptState* pOptState );
 
 LOCAL tSuccess
 doImmediateOpts( tOptions* pOpts );
@@ -43,7 +55,7 @@ parseAttributes(
     tOptionValue*       pType );
 
 LOCAL tSuccess
-validateOptionsStruct( tOptions* pOpts, const char* pzProgram );
+validateOptionsStruct( tOptions* pOpts, char const* pzProgram );
 
 /*
  *  Extracted from environment.c
