@@ -93,14 +93,14 @@ spec_init (void)
   if (!is_init)
     {
       extern spec_entry snv_default_spec_table[];
-      unsigned index = 0;
+      unsigned ix = 0;
 
       memset (spec_table, 0, sizeof (spec_table));
-      while (snv_default_spec_table[index].spec != EOS)
+      while (snv_default_spec_table[ix].spec_key != EOS)
 	{
-	  unsigned hash = spec_hash (snv_default_spec_table[index].spec);
-	  spec_table[hash] = snv_default_spec_table + index;
-	  index++;
+	  unsigned hash = spec_hash (snv_default_spec_table[ix].spec_key);
+	  spec_table[hash] = snv_default_spec_table + ix;
+	  ix++;
 	}
 #ifdef SNV_LIBRARY_BUILD
       snv_load_all_modules ();
@@ -113,7 +113,7 @@ spec_init (void)
 SNV_INLINE void
 spec_insert (spec_entry *pentry)
 {
-  unsigned hash = spec_hash (pentry->spec);
+  unsigned hash = spec_hash (pentry->spec_key);
   spec_init ();
   spec_table[hash] = pentry;
 }
@@ -133,10 +133,10 @@ spec_lookup (unsigned spec)
  * @fmt: the handler function to actually print the arguments to the specifier
  * @arg: the handler function to tell %printf about the types of the arguments
  *       to the specifier
- * 
+ *
  * Register the pair made of @fmt and @arg, so that it is called
  * when @spec is encountered in a format string.
- * 
+ *
  * Return value:
  * Returns %NULL if @func was not successfully registered, a
  * %spec_entry with the information on the function if it was.
@@ -153,7 +153,7 @@ register_printf_function (unsigned spec, printf_function *fmt, printf_arginfo_fu
     return NULL;
 
   new = snv_new (spec_entry, 1);
-  new->spec = spec;
+  new->spec_key = spec;
   new->fmt = fmt;
   new->arg = arg;
   new->user = NULL;
@@ -164,7 +164,10 @@ register_printf_function (unsigned spec, printf_function *fmt, printf_arginfo_fu
 }
 
 static int
-call_argtype_function (struct printf_info *const pinfo, int **argtypes, spec_entry *spec)
+call_argtype_function (
+    struct printf_info *const pinfo,
+    int **argtypes,
+    spec_entry *spec)
 {
   int n;
   int argindex = (pinfo->dollar && !IS_MODIFIER (spec))
@@ -205,30 +208,33 @@ call_argtype_function (struct printf_info *const pinfo, int **argtypes, spec_ent
 
   else
     {
-      pinfo->spec = *pinfo->format;
+      pinfo->spec  = (unsigned)*(pinfo->format);
       pinfo->extra = spec->user;
-      pinfo->type = spec->type;
+      pinfo->type  = spec->type;
 
       if (pinfo->argc > argindex)
-        n = spec->arg(pinfo, pinfo->argc - argindex, *argtypes + argindex);
+        n = spec->arg(pinfo, (unsigned)(pinfo->argc - argindex),
+		      *argtypes + argindex);
       else
         n = spec->arg(pinfo, 0, NULL);
 
       if (n < 0)
 	return n;
-      else if (argindex + n > pinfo->argc)
+      if (argindex + n > pinfo->argc)
         {
-	  *argtypes = snv_renew (int, *argtypes, argindex + n);
+          int new_ct = argindex + n;
+	  *argtypes = snv_renew (int, *argtypes, new_ct);
+          memset(*argtypes + pinfo->argc, PA_UNKNOWN,
+                 (new_ct - pinfo->argc) * sizeof(**argtypes));
 	  pinfo->argc = argindex + n;
-
 	  /* Call again... */
 	  pinfo->argindex = save_argindex;
-	  pinfo->format = save_format;
-	  pinfo->state = save_state;
-          pinfo->spec = *pinfo->format;
-          pinfo->extra = spec->user;
-          pinfo->type = spec->type;
-          n = spec->arg(pinfo, n, *argtypes + argindex);
+          pinfo->format   = save_format;
+          pinfo->state    = save_state;
+          pinfo->spec     = (unsigned)*(pinfo->format);
+          pinfo->extra    = spec->user;
+          pinfo->type     = spec->type;
+          n = spec->arg(pinfo, (unsigned)n, *argtypes + argindex);
 	}
     }
 
@@ -258,7 +264,10 @@ printf_strerror (void)
 
 /* (re)initialise the memory used by PPARSER. */
 static inline void
-parser_init (struct printf_info *pinfo, const char *format, const union printf_arg *args)
+parser_init (
+    struct printf_info *pinfo,
+    const char *format,
+    const union printf_arg *args)
 {
   memset (pinfo, 0, sizeof (struct printf_info));
   pinfo->format = format;
@@ -270,7 +279,7 @@ parser_reset (struct printf_info *pinfo)
 {
   pinfo->is_long_double = pinfo->is_char = pinfo->is_short =
     pinfo->is_long = pinfo->alt = pinfo->space = pinfo->left =
-    pinfo->showsign = pinfo->group = pinfo->wide = 
+    pinfo->showsign = pinfo->group = pinfo->wide =
     pinfo->width = pinfo->spec = 0;
 
   pinfo->state = SNV_STATE_BEGIN;
@@ -291,11 +300,11 @@ parser_reset (struct printf_info *pinfo)
  * @func2: function where error was detected, if supplied by compiler.
  * @func3: ")" if function is supplied by compiler.
  * @error_message: new error message to append to @pinfo.
- * 
+ *
  * The contents of @error_message are appended to the @pinfo internal
  * error string, so it is safe to pass static strings or recycle the
  * original when this function returns.
- * 
+ *
  * Return value:
  * The address of the full accumulated error message in @pinfo is
  * returned.
@@ -334,7 +343,7 @@ printf_error (struct printf_info *pinfo, const char *file, int line, const char
  * @format: a % delimited format string.
  * @n: the size of the @argtypes vector
  * @argtypes: a vector of ints, to be filled with the argument types from @format
- * 
+ *
  * Returns information about the number and types of
  * arguments expected by the template string @format.
  * The argument @n specifies the number of elements in the array
@@ -354,7 +363,7 @@ parse_printf_format (const char *format, int n, int *argtypes)
 {
   struct printf_info info;
 
-  return_val_if_fail (format != NULL, -1);
+  return_val_if_fail (format != NULL, (size_t)(-1));
 
   parser_init (&info, format, NULL);
 
@@ -381,7 +390,7 @@ parse_printf_format (const char *format, int n, int *argtypes)
 
 		  /* ...lookup the handler associated with the char
 		     we are looking at in the format string... */
-		  spec = spec_lookup (*info.format);
+		  spec = spec_lookup ((unsigned)*(info.format));
 		  if (spec == NULL)
 		    {
 		      PRINTF_ERROR (&info, "unregistered specifier");
@@ -401,10 +410,11 @@ parse_printf_format (const char *format, int n, int *argtypes)
 		  /* ...and call the relevant handler.  */
 		  if (spec->arg)
 		    {
-		      info.spec = *info.format;
-		      info.extra = spec->user;
-		      info.type = spec->type;
-		      status = (*spec->arg) (&info, n - argindex, argtypes + argindex);
+                      info.spec  = (unsigned)*(info.format);
+                      info.extra = spec->user;
+                      info.type  = spec->type;
+                      status     = (*spec->arg) (&info, (unsigned)(n - argindex),
+                                                 argtypes + argindex);
 		    }
 		  else
 		    {
@@ -434,9 +444,9 @@ parse_printf_format (const char *format, int n, int *argtypes)
         default:	/* Just a character: ignore it. */
 	  continue;
 	}
-     
-    error: 
-      /* Get here on error */ 
+
+    error:
+      /* Get here on error */
       info.argc = -1;
       break;
     }
@@ -476,7 +486,8 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
 	    {
 	      /* We found the start of a format specifier! */
 	      spec_entry *spec;
-	      int status, argindex;
+	      int status;
+	      int argindex;
 
 	      parser_reset (&info);
 	      do
@@ -487,7 +498,7 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
 
 		  /* ...lookup the handler associated with the char
 		     we are looking at in the format string... */
-		  spec = spec_lookup (*info.format);
+		  spec = spec_lookup ((unsigned)*(info.format));
 		  if (spec == NULL)
 		    {
 		      PRINTF_ERROR (&info, "unregistered specifier");
@@ -502,9 +513,9 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
 		    }
 
 		  /* ...and call the relevant handler. */
-		  info.spec = *info.format;
+		  info.spec  = (unsigned)*(info.format);
 		  info.extra = spec->user;
-		  info.type = spec->type;
+		  info.type  = spec->type;
 
 		  status = spec->arg ? (*spec->arg) (&info, 0, NULL) : 1;
 
@@ -535,14 +546,13 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
 
 	  /*NOBREAK*/
 
-        default:	/* Just a character: ignore it. */
-          /* Just a character: copy it. */
+	default:       /* Just a character: copy it. */
 	  SNV_EMIT (ch, stream, info.count);
 	  continue;
-        }
- 
-    error: 
-      /* Get here on error */ 
+	}
+
+    error:
+      /* Get here on error */
       info.count = -1;
       break;
     }
@@ -563,11 +573,11 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
  * @stream: an initialised stream structure.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to @stream.  If @stream is %NULL, only count the
  * number of characters needed to output the format.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -583,57 +593,61 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
   return_val_if_fail (format != NULL, SNV_ERROR);
 
   parser_init (&info, format, NULL);
+
+  /* Keep going until the format string runs out! */
   while (*info.format != EOS)
     {
       int ch = (int) *info.format++;
 
       switch (ch)
-       {
-       case SNV_CHAR_SPEC:
-         if (*info.format != SNV_CHAR_SPEC)
-           {
-             /* We found the start of a format specifier! */
-             spec_entry *spec;
+	{
+	case SNV_CHAR_SPEC:
+	  if (*info.format != SNV_CHAR_SPEC)
+	    {
+	      /* We found the start of a format specifier! */
+	      spec_entry *spec;
 
-             parser_reset (&info);
-             do
-               {
-                 /* Until we fill the stream (or get some other
-                    exception) or one of the handlers tells us
-                    we have reached the end of the specifier... */
-                 /* ...lookup the handler associated with the char
-                    we are looking at in the format string... */
-                 spec = spec_lookup (*info.format);
-                 if (spec == NULL)
-                   {
-                     PRINTF_ERROR (&info, "unregistered specifier");
-                     goto error;
-                   }
+	      parser_reset (&info);
+	      do
+		{
+		  /* Until we fill the stream (or get some other
+		     exception) or one of the handlers tells us
+		     we have reached the end of the specifier... */
 
-                 if (!IS_MODIFIER (spec) &&
-                     !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
-                   {
-                     PRINTF_ERROR (&info, "invalid combination of flags");
-                     goto error;
-                   }
+		  /* ...lookup the handler associated with the char
+		     we are looking at in the format string... */
+		  spec = spec_lookup ((unsigned)*(info.format));
+		  if (spec == NULL)
+		    {
+		      PRINTF_ERROR (&info, "unregistered specifier");
+		      goto error;
+		    }
 
-                 /* ...and call the relevant handler.  */
-                 if (call_argtype_function (&info, &argtypes, spec) < 0)
-                   goto error;
+		  if (!IS_MODIFIER (spec) &&
+		      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
+		    {
+		      PRINTF_ERROR (&info, "invalid combination of flags");
+		      goto error;
+		    }
 
-                 info.format++;
-               }
-             while (info.count >= 0 && IS_MODIFIER (spec));
-             continue;
-           }
-         /* An escaped CHAR_SPEC: ignore it (by falling through). */
-         ++info.format;
+		  /* ...and call the relevant handler. */
+		  if (call_argtype_function (&info, &argtypes, spec) < 0)
+		    goto error;
 
-         /*NOBREAK*/
+		  info.format++;
+		}
+	      while (info.count >= 0 && IS_MODIFIER (spec));
+	      continue;
+	    }
 
-        default:       /* Just a character: ignore it. */
-         continue;
-       }
+	  /* An escaped CHAR_SPEC: ignore it (by falling through). */
+	  ++info.format;
+
+	  /*NOBREAK*/
+
+	default:       /* Just a character: ignore it. */
+	  continue;
+	}
 
     error:
       /* Get here on error */
@@ -641,76 +655,98 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
       break;
     }
 
-  if (info.argc > 0)
+  if (info.argc == 0)
     {
-      int index;
+      args = NULL;
+    }
+  else
+    {
+      int idx;
 
       args = snv_new (union printf_arg, info.argc);
 
       /* We scanned the format string to find the type of the arguments,
          so we can now cast it and store it correctly.  */
-      for (index = 0; index < info.argc; index++)
-       switch (argtypes[index] & ~PA_FLAG_UNSIGNED)
-         {
-          case PA_CHAR:
-           args[index].pa_char = (char) *(const long int *)(ap + index);
-            break;
+      for (idx = 0; idx < info.argc; idx++)
+        {
+          int tp = argtypes[idx];
+          if ((tp & PA_TYPE_MASK) == PA_TYPE_MASK)
+            {
+              if (idx + 1 == info.argc)
+                {
+                  info.argc--;
+                  break;
+                }
+              continue; /* Ignore it.  We allow skipping args, but the
+                         * user is responsible for ensuring a void* sized
+                         * spacer in the argument list.
+                         */
+            }
 
-          case PA_WCHAR:
-           args[index].pa_wchar = (snv_wchar_t) *(const long int *)(ap + index);
-            break;
+          switch (tp & ~PA_FLAG_UNSIGNED)
+            {
+            case PA_CHAR:
+              args[idx].pa_char = (char) *(const long int *)(ap + idx);
+              break;
 
-          case PA_INT|PA_FLAG_SHORT:
-           args[index].pa_short_int = (short int) *(const long int *)(ap + index);
-            break;
+            case PA_WCHAR:
+              args[idx].pa_wchar =
+                (snv_wchar_t) *(const long int *)(ap + idx);
+              break;
 
-          case PA_INT:
-           args[index].pa_int = (int) *(const long int *)(ap + index);
-            break;
+            case PA_INT|PA_FLAG_SHORT:
+              args[idx].pa_short_int =
+                (short int) *(const long int *)(ap + idx);
+              break;
 
-          case PA_INT|PA_FLAG_LONG:
-           args[index].pa_long_int = *(const long int *)(ap + index);
-            break;
+            case PA_INT:
+              args[idx].pa_int = (int) *(const long int *)(ap + idx);
+              break;
 
-          case PA_INT|PA_FLAG_LONG_LONG:
-           args[index].pa_long_long_int = **(const intmax_t **)(ap + index);
-            break;
+            case PA_INT|PA_FLAG_LONG:
+              args[idx].pa_long_int = *(const long int *)(ap + idx);
+              break;
 
-          case PA_FLOAT:
-           args[index].pa_float = **(const float **)(ap + index);
-            break;
+            case PA_INT|PA_FLAG_LONG_LONG:
+              args[idx].pa_long_long_int = **(const intmax_t **)(ap + idx);
+              break;
 
-          case PA_DOUBLE|PA_FLAG_LONG_DOUBLE:
+            case PA_FLOAT:
+              args[idx].pa_float = **(const float **)(ap + idx);
+              break;
+
+            case PA_DOUBLE|PA_FLAG_LONG_DOUBLE:
 #ifdef HAVE_LONG_DOUBLE
-           args[index].pa_long_double = **(const long double **)(ap + index);
-            break;
+              args[idx].pa_long_double = **(const long double **)(ap + idx);
+              break;
 #endif
-           /* else fall through */
+              /* else fall through */
 
-          case PA_DOUBLE:
-           args[index].pa_double = **(const double **)(ap + index);
-            break;
+            case PA_DOUBLE:
+              args[idx].pa_double = **(const double **)(ap + idx);
+              break;
 
-         /* Note that pointer types are dereferenced just once! */
-          case PA_STRING:
-           args[index].pa_string = *(const char **)(ap + index);
-            break;
+              /* Note that pointer types are dereferenced just once! */
+            case PA_STRING:
+              args[idx].pa_string = *(const char **)(ap + idx);
+              break;
 
-          case PA_WSTRING:
-           args[index].pa_wstring = *(const snv_wchar_t **)(ap + index);
-            break;
+            case PA_WSTRING:
+              args[idx].pa_wstring = *(const snv_wchar_t **)(ap + idx);
+              break;
 
-          case PA_POINTER:
-           args[index].pa_pointer = *(snv_constpointer *)(ap + index);
-            break;
+            case PA_POINTER:
+              args[idx].pa_pointer = *(snv_constpointer *)(ap + idx);
+              break;
 
-         default:
-            if (argtypes[index] & PA_FLAG_PTR)
-              args[index].pa_pointer = *(snv_constpointer *)(ap + index);
-            else
-              args[index].pa_long_double = 0.0;
-            break;
-         }
+            default:
+              if (argtypes[idx] & PA_FLAG_PTR)
+                args[idx].pa_pointer = *(snv_constpointer *)(ap + idx);
+              else
+                args[idx].pa_long_double = 0.0;
+              break;
+            }
+        }
     }
 
   if (printf_last_error)
@@ -736,11 +772,11 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
  * @stream: an initialised stream structure.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to @stream.  If @stream is %NULL, only count the
  * number of characters needed to output the format.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -776,7 +812,7 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
 		     we have reached the end of the specifier... */
 		  /* ...lookup the handler associated with the char
 		     we are looking at in the format string... */
-		  spec = spec_lookup (*info.format);
+		  spec = spec_lookup ((unsigned)*(info.format));
 		  if (spec == NULL)
 		    {
 		      PRINTF_ERROR (&info, "unregistered specifier");
@@ -804,19 +840,19 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
 
 	  /*NOBREAK*/
 
-        default:	/* Just a character: ignore it. */
+        default: /* Just a character: ignore it. */
 	  continue;
 	}
-     
-    error: 
-      /* Get here on error */ 
+
+    error:
+      /* Get here on error */
       info.argc = -1;
       break;
     }
 
   if (info.argc > 0)
     {
-      int index;
+      int idx;
 
       args = snv_new (union printf_arg, info.argc);
 
@@ -831,62 +867,62 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
 
          Thanks to Robert Lipe <robertlipe@usa.net> for explaining all
          this to me. */
-      for (index = 0; index < info.argc; index++)
-	switch (argtypes[index] & ~PA_FLAG_UNSIGNED)
+      for (idx = 0; idx < info.argc; idx++)
+	switch (argtypes[idx] & ~PA_FLAG_UNSIGNED)
 	  {
           case PA_CHAR:
-	    args[index].pa_char = va_arg (ap, int); /* Promoted.  */
+	    args[idx].pa_char = va_arg (ap, int); /* Promoted.  */
             break;
 
           case PA_WCHAR:
-	    args[index].pa_wchar = va_arg (ap, snv_wint_t); /* Promoted.  */
+	    args[idx].pa_wchar = va_arg (ap, snv_wint_t); /* Promoted.  */
             break;
 
           case PA_INT|PA_FLAG_SHORT:
-	    args[index].pa_short_int = va_arg (ap, int); /* Promoted.  */
+	    args[idx].pa_short_int = va_arg (ap, int); /* Promoted.  */
             break;
 
           case PA_INT:
-	    args[index].pa_int = va_arg (ap, int);
+	    args[idx].pa_int = va_arg (ap, int);
             break;
-  
+
           case PA_INT|PA_FLAG_LONG:
-	    args[index].pa_long_int = va_arg (ap, long int);
+	    args[idx].pa_long_int = va_arg (ap, long int);
             break;
 
           case PA_INT|PA_FLAG_LONG_LONG:
-	    args[index].pa_long_long_int = va_arg (ap, intmax_t);
+	    args[idx].pa_long_long_int = va_arg (ap, intmax_t);
             break;
 
           case PA_FLOAT:
-	    args[index].pa_float = va_arg (ap, double); /* Promoted.  */
+	    args[idx].pa_float = va_arg (ap, double); /* Promoted.  */
             break;
 
           case PA_DOUBLE|PA_FLAG_LONG_DOUBLE:
-	    args[index].pa_long_double = va_arg (ap, long double);
+	    args[idx].pa_long_double = va_arg (ap, long double);
             break;
 
           case PA_DOUBLE:
-	    args[index].pa_double = va_arg (ap, double);
+	    args[idx].pa_double = va_arg (ap, double);
             break;
 
           case PA_STRING:
-	    args[index].pa_string = va_arg (ap, const char *);
+	    args[idx].pa_string = va_arg (ap, const char *);
             break;
 
           case PA_WSTRING:
-	    args[index].pa_wstring = va_arg (ap, const snv_wchar_t *);
+	    args[idx].pa_wstring = va_arg (ap, const snv_wchar_t *);
             break;
 
           case PA_POINTER:
-	    args[index].pa_pointer = va_arg (ap, void *);
+	    args[idx].pa_pointer = va_arg (ap, void *);
             break;
 
 	  default:
-            if (argtypes[index] & PA_FLAG_PTR)
-              args[index].pa_pointer = va_arg (ap, void *);
+            if (argtypes[idx] & PA_FLAG_PTR)
+              args[idx].pa_pointer = va_arg (ap, void *);
             else
-              args[index].pa_long_double = 0.0;
+              args[idx].pa_long_double = 0.0;
             break;
 	  }
     }
@@ -911,11 +947,11 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
  * @stream: an initialised stream structure.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to @stream.  If @stream is %NULL, only count the
  * number of characters needed to output the format.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -940,10 +976,10 @@ stream_printf (STREAM * stream, const char *format, ...)
  * snv_fdputc: printf.h
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
- * 
+ *
  * A StreamPut function for use in putting characters
  * into STREAMs holding a file descriptor.
- * 
+ *
  * Return value:
  * The value of @ch that has been put in @stream, or -1 in case of
  * an error (errno will be set to indicate the type of error).
@@ -961,10 +997,10 @@ snv_fdputc (int ch, STREAM *stream)
  * @fd: an open file descriptor.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the file descriptor @fd.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -987,10 +1023,10 @@ snv_dprintf (int fd, const char *format, ...)
  * @fd: an open file descriptor.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the file descriptor @fd.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1012,10 +1048,10 @@ snv_vdprintf (int fd, const char *format, va_list ap)
  * @fd: an open file descriptor.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to file descriptor @fd.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1037,11 +1073,11 @@ snv_dprintfv (int fd, const char *format, snv_constpointer const args[])
  * snv_fileputc: printf.h
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
- * 
+ *
  * A StreamPut function for use in putting characters
  * into STREAMs holding a FILE*.
- * 
- * Return value: 
+ *
+ * Return value:
  * The value of @ch that has been put in @stream.
  **/
 int
@@ -1055,10 +1091,10 @@ snv_fileputc (int ch, STREAM *stream)
  * snv_printf: printf.h
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the standard output stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1080,10 +1116,10 @@ snv_printf (const char *format, ...)
  * snv_vprintf: printf.h
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the standard output stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1103,10 +1139,10 @@ snv_vprintf (const char *format, va_list ap)
  * snv_printfv: printf.h
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to the string @format,
  * and write the result to the standard output stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1127,10 +1163,10 @@ snv_printfv (const char *format, snv_constpointer const args[])
  * @file: a stdio.h FILE* stream.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the @file stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1153,10 +1189,10 @@ snv_fprintf (FILE * file, const char *format, ...)
  * @file: a stdio.h FILE* stream.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the @file stream.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1177,10 +1213,10 @@ snv_vfprintf (FILE *file, const char *format, va_list ap)
  * @file: a stdio.h FILE* stream.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to @file.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1201,10 +1237,10 @@ snv_fprintfv (FILE *file, const char *format, snv_constpointer const args[])
  * snv_bufputc: printf.h
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
- * 
+ *
  * A StreamPut function for use in putting characters
  * into STREAMs holding a char buffer.
- * 
+ *
  * Return value:
  * The value of @ch that has been put in @stream.
  **/
@@ -1224,10 +1260,10 @@ snv_bufputc (ch, stream)
  * @buffer: a preallocated char* buffer.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the string @buffer.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1250,10 +1286,10 @@ snv_sprintf (char buffer[], const char *format, ...)
  * @buffer: a preallocated char* buffer.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the string @buffer.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1277,10 +1313,10 @@ snv_vsprintf (char buffer[], const char *format, va_list ap)
  * @buffer: a preallocated char* buffer.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to the string @buffer.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1305,11 +1341,11 @@ snv_sprintfv (char buffer[], const char *format, snv_constpointer const args[])
  * @limit: the maximum number of characters to write into @buffer.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to the string @buffer, truncating the formatted string
  * if it reaches @limit characters in length.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1333,11 +1369,11 @@ snv_snprintf (char buffer[], unsigned long limit, const char *format, ...)
  * @limit: the maximum number of characters to write into @buffer.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to the string @buffer, truncating the formatted string
  * if it reaches @limit characters in length.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1360,11 +1396,11 @@ snv_vsnprintf (char buffer[], unsigned long limit, const char *format, va_list a
  * @limit: the maximum number of characters to write into @buffer.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to the string @buffer, truncating the formatted string
  * if it reaches @limit characters in length.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1386,11 +1422,11 @@ snv_snprintfv (char buffer[], unsigned long limit, const char *format, snv_const
  * snv_filputc: printf.h
  * @ch: A single character to be added to @stream.
  * @stream: The stream in which to write @ch.
- * 
+ *
  * A StreamPut function for use in putting characters
  * into STREAMs holding a Filament*.
- * 
- * Return value: 
+ *
+ * Return value:
  * The value of @ch that has been put in @stream.
  **/
 int
@@ -1406,7 +1442,7 @@ snv_filputc (ch, stream)
  * @result: the address of a char * variable.
  * @format: a % delimited format string.
  * @va_alist: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @va_alist according to @format, and write
  * the results to an internally allocated buffer whose address is
  * stored in @result (and should be freed by the caller) unless
@@ -1414,9 +1450,9 @@ snv_filputc (ch, stream)
  *
  * Yes, this interface is cumbersome and totally useless.  It would
  * have been better to simply return the allocated address, but
- * it turns out that somebody wasn't thinking much when adding 
+ * it turns out that somebody wasn't thinking much when adding
  * asprintf to libiberty a few years ago.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1439,12 +1475,12 @@ snv_asprintf (char **result, const char *format, ...)
  * @result: the address of a char * variable.
  * @format: a % delimited format string.
  * @ap: a varargs/stdargs va_list.
- * 
+ *
  * Format the elements of @ap according to @format, and write
  * the results to an internally allocated buffer whose address is
  * stored in @result (and should be freed by the caller) unless
  * there is an error.
- * 
+ *
  * Above moaning for asprintf applies here too.
  *
  * Return value:
@@ -1472,14 +1508,14 @@ snv_vasprintf (char **result, const char *format, va_list ap)
  * @result: the address of a char * variable.
  * @format: a % delimited format string.
  * @args: a vector of argument addresses to match @format.
- * 
+ *
  * Format the elements of @args according to @format, and write
  * the results to an internally allocated buffer whose address is
  * stored in @result (and should be freed by the caller) unless
  * there is an error.
- * 
+ *
  * Above moaning for asprintf applies here too.
- * 
+ *
  * Return value:
  * The number of characters written is returned, unless there is
  * an error, when %SNV_ERROR is returned.
@@ -1503,8 +1539,7 @@ snv_asprintfv (char **result, const char *format, snv_constpointer const args[])
 /*
  * Local Variables:
  * mode: C
- * c-file-style: "stroustrup"
- * tab-width: 4
+ * c-file-style: "gnu"
  * indent-tabs-mode: nil
  * End:
  * end of snprintfv/printfv.c */
